@@ -4,24 +4,26 @@ describe 'ceilometer' do
 
   let :params do
     {
-      :http_timeout               => '600',
-      :event_time_to_live         => '604800',
-      :metering_time_to_live      => '604800',
-      :telemetry_secret           => 'metering-s3cr3t',
-      :package_ensure             => 'present',
-      :debug                      => 'False',
-      :log_dir                    => '/var/log/ceilometer',
-      :use_stderr                 => 'True',
-      :purge_config               => false,
+      :http_timeout          => '600',
+      :event_time_to_live    => '604800',
+      :metering_time_to_live => '604800',
+      :telemetry_secret      => 'metering-s3cr3t',
+      :package_ensure        => 'present',
+      :debug                 => 'False',
+      :log_dir               => '/var/log/ceilometer',
+      :use_stderr            => 'True',
+      :purge_config          => false,
+      :host                  => 'foo.domain'
     }
   end
 
   let :rabbit_params do
     {
-      :rabbit_host        => '127.0.0.1',
-      :rabbit_port        => 5672,
-      :rabbit_userid      => 'guest',
-      :rabbit_password    => '',
+      :rabbit_host               => '127.0.0.1',
+      :rabbit_port               => 5672,
+      :rabbit_userid             => 'guest',
+      :rabbit_password           => '',
+      :rabbit_qos_prefetch_count => 10,
     }
   end
 
@@ -36,6 +38,10 @@ describe 'ceilometer' do
       is_expected.to contain_ceilometer_config('DEFAULT/http_timeout').with_value(params[:http_timeout])
     end
 
+    it 'configures host name' do
+      is_expected.to contain_ceilometer_config('DEFAULT/host').with_value(params[:host])
+    end
+
     context 'with rabbit_host parameter' do
       before { params.merge!( rabbit_params ) }
       it_configures 'a ceilometer base installation'
@@ -65,13 +71,9 @@ describe 'ceilometer' do
         it_configures 'rabbit with HA support'
       end
 
-      context("with legacy rpc_backend value") do
-        before { params.merge!( rabbit_params ).merge!(:rpc_backend => 'ceilometer.openstack.common.rpc.impl_kombu') }
-        it { is_expected.to contain_ceilometer_config('DEFAULT/rpc_backend').with_value('rabbit') }
-      end
     end
 
-    context 'with amqp rpc_backend value' do
+    context 'with amqp messaging' do
       it_configures 'amqp support'
     end
 
@@ -84,17 +86,19 @@ describe 'ceilometer' do
 
     it 'configures ceilometer group' do
       is_expected.to contain_group('ceilometer').with(
+        :ensure  => 'present',
         :name    => 'ceilometer',
-        :require => 'Package[ceilometer-common]'
+        :require => 'Anchor[ceilometer::install::end]'
       )
     end
 
     it 'configures ceilometer user' do
       is_expected.to contain_user('ceilometer').with(
+        :ensure  => 'present',
         :name    => 'ceilometer',
         :gid     => 'ceilometer',
         :system  => true,
-        :require => 'Package[ceilometer-common]'
+        :require => 'Anchor[ceilometer::install::end]'
       )
     end
 
@@ -124,23 +128,55 @@ describe 'ceilometer' do
 
     it 'configures default transport_url' do
       is_expected.to contain_ceilometer_config('DEFAULT/transport_url').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_ceilometer_config('DEFAULT/rpc_response_timeout').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_ceilometer_config('DEFAULT/control_exchange').with_value('<SERVICE DEFAULT>')
     end
 
     it 'configures notifications' do
       is_expected.to contain_ceilometer_config('oslo_messaging_notifications/topics').with_value('notifications')
+      is_expected.to contain_ceilometer_config('oslo_messaging_notifications/driver').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_ceilometer_config('oslo_messaging_notifications/transport_url').with_value('<SERVICE DEFAULT>')
     end
 
+    it 'configures snmpd auth' do
+      is_expected.to contain_ceilometer_config('hardware/readonly_user_name').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_ceilometer_config('hardware/readonly_user_password').with_value('<SERVICE DEFAULT>')
+    end
+
+    it 'configures cache backend' do
+      is_expected.to contain_ceilometer_config('cache/memcache_servers').with_value('<SERVICE DEFAULT>')
+    end
+
     context 'with rabbitmq durable queues configured' do
       before { params.merge!( :amqp_durable_queues => true ) }
       it_configures 'rabbit with durable queues'
     end
 
     context 'with overriden transport_url parameter' do
-      before { params.merge!( :default_transport_url => 'rabbit://rabbit_user:password@localhost:5673' ) }
+      before {
+        params.merge!(
+          :default_transport_url => 'rabbit://rabbit_user:password@localhost:5673',
+          :rpc_response_timeout  => '120',
+          :control_exchange      => 'ceilometer',
+        )
+      }
 
       it 'configures transport_url' do
         is_expected.to contain_ceilometer_config('DEFAULT/transport_url').with_value('rabbit://rabbit_user:password@localhost:5673')
+        is_expected.to contain_ceilometer_config('DEFAULT/rpc_response_timeout').with_value('120')
+        is_expected.to contain_ceilometer_config('DEFAULT/control_exchange').with_value('ceilometer')
+      end
+    end
+
+    context 'with overriden cache parameter' do
+      before {
+        params.merge!(
+          :memcache_servers => 'host1:11211,host2:11211',
+        )
+      }
+
+      it 'configures cache backend' do
+        is_expected.to contain_ceilometer_config('cache/memcache_servers').with_value('host1:11211,host2:11211')
       end
     end
 
@@ -148,12 +184,14 @@ describe 'ceilometer' do
       before {
         params.merge!(
           :notification_topics        => ['notifications', 'custom'],
+          :notification_driver        => 'messagingv1',
           :notification_transport_url => 'rabbit://rabbit_user:password@localhost:5673',
         )
       }
 
       it 'configures notifications' do
         is_expected.to contain_ceilometer_config('oslo_messaging_notifications/topics').with_value('notifications,custom')
+        is_expected.to contain_ceilometer_config('oslo_messaging_notifications/driver').with_value('messagingv1')
         is_expected.to contain_ceilometer_config('oslo_messaging_notifications/transport_url').with_value('rabbit://rabbit_user:password@localhost:5673')
       end
     end
@@ -172,8 +210,10 @@ describe 'ceilometer' do
 
     it { is_expected.to contain_ceilometer_config('oslo_messaging_rabbit/rabbit_host').with_value( params[:rabbit_host] ) }
     it { is_expected.to contain_ceilometer_config('oslo_messaging_rabbit/rabbit_port').with_value( params[:rabbit_port] ) }
+    it { is_expected.to contain_ceilometer_config('oslo_messaging_rabbit/rabbit_qos_prefetch_count').with_value( params[:rabbit_qos_prefetch_count] ) }
     it { is_expected.to contain_ceilometer_config('oslo_messaging_rabbit/rabbit_hosts').with_value('<SERVICE DEFAULT>') }
     it { is_expected.to contain_ceilometer_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('<SERVICE DEFAULT>') }
+    it { is_expected.to contain_ceilometer_config('oslo_messaging_rabbit/kombu_failover_strategy').with_value('<SERVICE DEFAULT>') }
 
   end
 
@@ -190,8 +230,10 @@ describe 'ceilometer' do
 
     it { is_expected.to contain_ceilometer_config('oslo_messaging_rabbit/rabbit_host').with_value('<SERVICE DEFAULT>') }
     it { is_expected.to contain_ceilometer_config('oslo_messaging_rabbit/rabbit_port').with_value('<SERVICE DEFAULT>') }
+    it { is_expected.to contain_ceilometer_config('oslo_messaging_rabbit/rabbit_qos_prefetch_count').with_value( params[:rabbit_qos_prefetch_count] ) }
     it { is_expected.to contain_ceilometer_config('oslo_messaging_rabbit/rabbit_hosts').with_value( params[:rabbit_hosts].join(',') ) }
     it { is_expected.to contain_ceilometer_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('<SERVICE DEFAULT>') }
+    it { is_expected.to contain_ceilometer_config('oslo_messaging_rabbit/kombu_failover_strategy').with_value('<SERVICE DEFAULT>') }
 
   end
 
@@ -215,6 +257,7 @@ describe 'ceilometer' do
 
     it { is_expected.to contain_ceilometer_config('oslo_messaging_rabbit/rabbit_host').with_value('<SERVICE DEFAULT>') }
     it { is_expected.to contain_ceilometer_config('oslo_messaging_rabbit/rabbit_port').with_value('<SERVICE DEFAULT>') }
+    it { is_expected.to contain_ceilometer_config('oslo_messaging_rabbit/rabbit_qos_prefetch_count').with_value( params[:rabbit_qos_prefetch_count] ) }
     it { is_expected.to contain_ceilometer_config('oslo_messaging_rabbit/rabbit_hosts').with_value( params[:rabbit_hosts].join(',') ) }
     it { is_expected.to contain_ceilometer_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value(true) }
 
@@ -258,11 +301,13 @@ describe 'ceilometer' do
 
   shared_examples_for 'rabbit with SSL support' do
     context "with default parameters" do
-      it { is_expected.to contain_ceilometer_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value('<SERVICE DEFAULT>') }
-      it { is_expected.to contain_ceilometer_config('oslo_messaging_rabbit/kombu_ssl_ca_certs').with_value('<SERVICE DEFAULT>') }
-      it { is_expected.to contain_ceilometer_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_value('<SERVICE DEFAULT>') }
-      it { is_expected.to contain_ceilometer_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_value('<SERVICE DEFAULT>') }
-      it { is_expected.to contain_ceilometer_config('oslo_messaging_rabbit/kombu_ssl_version').with_value('<SERVICE DEFAULT>') }
+    it { is_expected.to contain_oslo__messaging__rabbit('ceilometer_config').with(
+      :rabbit_use_ssl     => '<SERVICE DEFAULT>',
+      :kombu_ssl_ca_certs => '<SERVICE DEFAULT>',
+      :kombu_ssl_certfile => '<SERVICE DEFAULT>',
+      :kombu_ssl_keyfile  => '<SERVICE DEFAULT>',
+      :kombu_ssl_version  => '<SERVICE DEFAULT>',
+    )}
     end
 
     context "with SSL enabled with kombu" do
@@ -274,11 +319,13 @@ describe 'ceilometer' do
         :kombu_ssl_version  => 'TLSv1'
       ) }
 
-      it { is_expected.to contain_ceilometer_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value(true) }
-      it { is_expected.to contain_ceilometer_config('oslo_messaging_rabbit/kombu_ssl_ca_certs').with_value('/path/to/ca.crt') }
-      it { is_expected.to contain_ceilometer_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_value('/path/to/cert.crt') }
-      it { is_expected.to contain_ceilometer_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_value('/path/to/cert.key') }
-      it { is_expected.to contain_ceilometer_config('oslo_messaging_rabbit/kombu_ssl_version').with_value('TLSv1') }
+    it { is_expected.to contain_oslo__messaging__rabbit('ceilometer_config').with(
+      :rabbit_use_ssl     => true,
+      :kombu_ssl_ca_certs => '/path/to/ca.crt',
+      :kombu_ssl_certfile => '/path/to/cert.crt',
+      :kombu_ssl_keyfile  => '/path/to/cert.key',
+      :kombu_ssl_version  => 'TLSv1'
+    )}
     end
 
     context "with SSL enabled without kombu" do
@@ -286,11 +333,9 @@ describe 'ceilometer' do
         :rabbit_use_ssl  => true
       ) }
 
-      it { is_expected.to contain_ceilometer_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value(true) }
-      it { is_expected.to contain_ceilometer_config('oslo_messaging_rabbit/kombu_ssl_ca_certs').with_value('<SERVICE DEFAULT>') }
-      it { is_expected.to contain_ceilometer_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_value('<SERVICE DEFAULT>') }
-      it { is_expected.to contain_ceilometer_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_value('<SERVICE DEFAULT>') }
-      it { is_expected.to contain_ceilometer_config('oslo_messaging_rabbit/kombu_ssl_version').with_value('<SERVICE DEFAULT>') }
+    it { is_expected.to contain_oslo__messaging__rabbit('ceilometer_config').with(
+      :rabbit_use_ssl     => true,
+    )}
     end
 
     context "with SSL wrongly configured" do
@@ -323,9 +368,6 @@ describe 'ceilometer' do
 
   shared_examples_for 'amqp support' do
     context 'with default parameters' do
-      before { params.merge!( :rpc_backend => 'amqp' ) }
-
-      it { is_expected.to contain_ceilometer_config('DEFAULT/rpc_backend').with_value('amqp') }
       it { is_expected.to contain_ceilometer_config('oslo_messaging_amqp/server_request_prefix').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_ceilometer_config('oslo_messaging_amqp/broadcast_prefix').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_ceilometer_config('oslo_messaging_amqp/group_request_prefix').with_value('<SERVICE DEFAULT>') }
@@ -346,7 +388,6 @@ describe 'ceilometer' do
 
     context 'with overriden amqp parameters' do
       before { params.merge!(
-        :rpc_backend        => 'amqp',
         :amqp_idle_timeout  => '60',
         :amqp_trace         => true,
         :amqp_ssl_ca_file   => '/path/to/ca.cert',
@@ -356,7 +397,6 @@ describe 'ceilometer' do
         :amqp_password      => 'password',
       ) }
 
-      it { is_expected.to contain_ceilometer_config('DEFAULT/rpc_backend').with_value('amqp') }
       it { is_expected.to contain_ceilometer_config('oslo_messaging_amqp/server_request_prefix').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_ceilometer_config('oslo_messaging_amqp/broadcast_prefix').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_ceilometer_config('oslo_messaging_amqp/group_request_prefix').with_value('<SERVICE DEFAULT>') }
@@ -375,27 +415,25 @@ describe 'ceilometer' do
     end
   end
 
-  context 'on Debian platforms' do
-    let :facts do
-      @default_facts.merge({ :osfamily => 'Debian' })
-    end
+  on_supported_os({
+    :supported_os => OSDefaults.get_supported_os
+  }).each do |os,facts|
+    context "on #{os}" do
+      let (:facts) do
+        facts.merge!(OSDefaults.get_facts())
+      end
 
-    let :platform_params do
-      { :common_package_name => 'ceilometer-common' }
-    end
+      let :platform_params do
+        case facts[:osfamily]
+        when 'Debian'
+          { :common_package_name => 'ceilometer-common' }
+        when 'RedHat'
+          { :common_package_name => 'openstack-ceilometer-common' }
+        end
+      end
 
-    it_configures 'ceilometer'
+      it_behaves_like 'ceilometer'
+    end
   end
 
-  context 'on RedHat platforms' do
-    let :facts do
-      @default_facts.merge({ :osfamily => 'RedHat' })
-    end
-
-    let :platform_params do
-      { :common_package_name => 'openstack-ceilometer-common' }
-    end
-
-    it_configures 'ceilometer'
-  end
 end
